@@ -1,5 +1,5 @@
 ## File Name: source.Rcpp.all.R
-## File Version: 0.37
+## File Version: 0.396
 
 # function for sourcing Rcpp files
 source.Rcpp.all <- function( path, file_names=NULL, ext="\\.cpp", excl="RcppExports",
@@ -21,9 +21,11 @@ source.Rcpp.all <- function( path, file_names=NULL, ext="\\.cpp", excl="RcppExpo
     file_source <- NULL
     for (ff in 1:NF){
         file_name <- file_names[ff]
-        file <- grep( file_name, files0, value=TRUE)
+        file <- grep( file_name, files0, value=TRUE, fixed=TRUE)
         file_source <- c( file_source, file )
     }
+    file_source0 <- file_source
+
     s1 <- lapply( strsplit( file_source, split="__" ), FUN=function(ll){ ll[[1]][1] } )
     file_source <- unique(unlist(s1))
 
