@@ -1,5 +1,5 @@
 ## File Name: sumpreserving.rounding.R
-## File Version: 0.13
+## File Version: 0.142
 
 
 sumpreserving.rounding <- function (data, digits=0, preserve=TRUE )
@@ -11,7 +11,8 @@ sumpreserving.rounding <- function (data, digits=0, preserve=TRUE )
         data.r[, 1] <- round(data[, 1], digits)
         err.r[, 1] <- data[, 1] - data.r[, 1]
         for (dd in 2:DD) {
-            data.r[, dd] <- round(data[, dd] + rowSums(err.r[, 1:(dd - 1),drop=FALSE]), digits)
+            data.r[, dd] <- round(data[, dd] + rowSums(err.r[, 1:(dd - 1),drop=FALSE]),
+                                    digits)
             err.r[, dd] <- data[, dd] - data.r[, dd]
         }
         if (is.data.frame(data)){
@@ -28,7 +29,9 @@ sumpreserving.rounding <- function (data, digits=0, preserve=TRUE )
             data.r[dd] <- round(data[dd] + sum(err.r[1:(dd - 1)]), digits)
             err.r[dd] <- data[dd] - data.r[dd]
         }
-        if ( ! preserve ){ data.r <- round( data, digits ) }
+        if ( ! preserve ){
+            data.r <- round( data, digits )
+        }
     }
     return(data.r)
 }
